.. stsci.convolve documentation master file, created by
   Warren Hack on Wed Sep 26, 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Image's documentation!
======================================

This package contains various functions for performing processing of images.

Modules:

.. toctree::
   :maxdepth: 2

   image
   numcombine
      
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

